@@ -1,8 +1,10 @@
 from .factory import AzureCLI
 
-az = AzureCLI
+TEST = True
+if not TEST: az = AzureCLI
 
 from .user import AzureUser, AzureCLIUser, Subscription, UserSession
 from .sp import SPUser, ServicePrincipalCreds, ServicePrincipalContext, AzureCLIServicePrincipal
 from .app_registration import AzureCLIAppRegistration, AppRegistrationCreds
-from .graph_api import GraphAPI, Organization, Me
\ No newline at end of file
+from .models import Me, Organization
+from .pkg_graph_api import GraphAPI
